==> opencl-clhpp-2.0.15-1-any.pkg.tar.xz: usr/share/doc/opencl-clhpp/navtreeindex2.js <==
var NAVTREEINDEX2 =
{
"classcl_1_1_platform.html#a436c09964ac6314a3763f5c15fb92e7d":[4,0,0,28,3],
"classcl_1_1_platform.html#a616344e02c3723347c752c02b7015212":[5,0,0,28,0],
"classcl_1_1_platform.html#a616344e02c3723347c752c02b7015212":[4,0,0,28,0],
"classcl_1_1_platform.html#a70313ea76e0e369c4dc951a7f47b531f":[4,0,0,28,6],
"classcl_1_1_platform.html#a70313ea76e0e369c4dc951a7f47b531f":[5,0,0,28,6],
"classcl_1_1_platform.html#a73cf4b02df3beafae1a97a91ee3e9565":[5,0,0,28,2],
"classcl_1_1_platform.html#a73cf4b02df3beafae1a97a91ee3e9565":[4,0,0,28,2],
"classcl_1_1_platform.html#aeaee2d9f15f2927c4a0467cc734a29a3":[5,0,0,28,5],
"classcl_1_1_platform.html#aeaee2d9f15f2927c4a0467cc734a29a3":[4,0,0,28,5],
"classcl_1_1_platform.html#af19b9194c46f545ffe62950f6e7cf377":[5,0,0,28,4],
"classcl_1_1_platform.html#af19b9194c46f545ffe62950f6e7cf377":[4,0,0,28,4],
"classcl_1_1_program.html":[5,0,0,29],
"classcl_1_1_program.html":[4,0,0,29],
"classcl_1_1_program.html#a0ec5552449e9fefc46e7bcd399d15f51":[5,0,0,29,7],
"classcl_1_1_program.html#a0ec5552449e9fefc46e7bcd399d15f51":[4,0,0,29,7],
"classcl_1_1_program.html#a1666a02c393b46730b24a76f79302b15":[5,0,0,29,8],
"classcl_1_1_program.html#a1666a02c393b46730b24a76f79302b15":[4,0,0,29,8],
"classcl_1_1_program.html#a2291de601ea1be9dd6fbb00441b66f11":[5,0,0,29,11],
"classcl_1_1_program.html#a2291de601ea1be9dd6fbb00441b66f11":[4,0,0,29,11],
"classcl_1_1_program.html#a367cf581b43d8ad021806a4714753437":[5,0,0,29,0],
"classcl_1_1_program.html#a367cf581b43d8ad021806a4714753437":[4,0,0,29,0],
"classcl_1_1_program.html#a400d1a7de104d98f1d3c2aa7dccc21ba":[5,0,0,29,1],
"classcl_1_1_program.html#a400d1a7de104d98f1d3c2aa7dccc21ba":[4,0,0,29,1],
"classcl_1_1_program.html#a4f03f90dcd6c7b48687af389cf8b25ca":[5,0,0,29,2],
"classcl_1_1_program.html#a4f03f90dcd6c7b48687af389cf8b25ca":[4,0,0,29,2],
"classcl_1_1_program.html#a6722c3f9459432087d82c5ff4d16a72e":[5,0,0,29,12],
"classcl_1_1_program.html#a6722c3f9459432087d82c5ff4d16a72e":[4,0,0,29,12],
"classcl_1_1_program.html#a7bd4452820d5b500c79aba740574d860":[5,0,0,29,10],
"classcl_1_1_program.html#a7bd4452820d5b500c79aba740574d860":[4,0,0,29,10],
"classcl_1_1_program.html#a9223820e8ac1901a84e1a1a02a97954b":[5,0,0,29,5],
"classcl_1_1_program.html#a9223820e8ac1901a84e1a1a02a97954b":[4,0,0,29,5],
"classcl_1_1_program.html#a9fefc53ce623dd7180260d83fc991ca4":[5,0,0,29,14],
"classcl_1_1_program.html#a9fefc53ce623dd7180260d83fc991ca4":[4,0,0,29,14],
"classcl_1_1_program.html#aaac370eec783f85a00945d701d6a7e19":[4,0,0,29,6],
"classcl_1_1_program.html#aaac370eec783f85a00945d701d6a7e19":[5,0,0,29,6],
"classcl_1_1_program.html#aab03a729b8b192ec11c18cb02856299f":[4,0,0,29,9],
"classcl_1_1_program.html#aab03a729b8b192ec11c18cb02856299f":[5,0,0,29,9],
"classcl_1_1_program.html#aca8d65a532ffd042fa45f88addcb9c88":[4,0,0,29,13],
"classcl_1_1_program.html#aca8d65a532ffd042fa45f88addcb9c88":[5,0,0,29,13],
"classcl_1_1_program.html#af804a4cb0e2dc844c0be0b0b76dbd25a":[5,0,0,29,4],
"classcl_1_1_program.html#af804a4cb0e2dc844c0be0b0b76dbd25a":[4,0,0,29,4],
"classcl_1_1_program.html#afeec80b90b56f6407b138b9e8f10e8bc":[5,0,0,29,3],
"classcl_1_1_program.html#afeec80b90b56f6407b138b9e8f10e8bc":[4,0,0,29,3],
"classcl_1_1_s_v_m_allocator.html":[5,0,0,31],
"classcl_1_1_s_v_m_allocator.html":[4,0,0,31],
"classcl_1_1_s_v_m_allocator.html#a44858d70971c7801aa62d7a64d18df00":[5,0,0,31,1],
"classcl_1_1_s_v_m_allocator.html#a44858d70971c7801aa62d7a64d18df00":[4,0,0,31,1],
"classcl_1_1_s_v_m_allocator.html#abaa89b1232891a728d3530dbd71e7cb6":[4,0,0,31,3],
"classcl_1_1_s_v_m_allocator.html#abaa89b1232891a728d3530dbd71e7cb6":[5,0,0,31,3],
"classcl_1_1_s_v_m_allocator.html#aec263261a88fb1ec64a3e5f9a4ef41a7":[4,0,0,31,2],
"classcl_1_1_s_v_m_allocator.html#aec263261a88fb1ec64a3e5f9a4ef41a7":[5,0,0,31,2],
"classcl_1_1_s_v_m_allocator_3_01void_00_01_s_v_m_trait_01_4.html":[4,0,0,32],
"classcl_1_1_s_v_m_allocator_3_01void_00_01_s_v_m_trait_01_4.html":[5,0,0,32],
"classcl_1_1_s_v_m_trait_atomic.html":[4,0,0,33],
"classcl_1_1_s_v_m_trait_atomic.html":[5,0,0,33],
"classcl_1_1_s_v_m_trait_coarse.html":[5,0,0,34],
"classcl_1_1_s_v_m_trait_coarse.html":[4,0,0,34],
"classcl_1_1_s_v_m_trait_fine.html":[5,0,0,35],
"classcl_1_1_s_v_m_trait_fine.html":[4,0,0,35],
"classcl_1_1_s_v_m_trait_read_only.html":[4,0,0,36],
"classcl_1_1_s_v_m_trait_read_only.html":[5,0,0,36],
"classcl_1_1_s_v_m_trait_read_write.html":[4,0,0,37],
"classcl_1_1_s_v_m_trait_read_write.html":[5,0,0,37],
"classcl_1_1_s_v_m_trait_write_only.html":[5,0,0,38],
"classcl_1_1_s_v_m_trait_write_only.html":[4,0,0,38],
"classcl_1_1_sampler.html":[5,0,0,30],
"classcl_1_1_sampler.html":[4,0,0,30],
"classcl_1_1_sampler.html#a1c8395b386e3b1c09dc43f4134909390":[5,0,0,30,0],
"classcl_1_1_sampler.html#a1c8395b386e3b1c09dc43f4134909390":[4,0,0,30,0],
"classcl_1_1_sampler.html#a21ef913d8118b7e8f7e2e9bf5c9251a7":[5,0,0,30,9],
"classcl_1_1_sampler.html#a21ef913d8118b7e8f7e2e9bf5c9251a7":[4,0,0,30,9],
"classcl_1_1_sampler.html#a41d7df0a069717bc570a6ccdab3d3acd":[4,0,0,30,1],
"classcl_1_1_sampler.html#a41d7df0a069717bc570a6ccdab3d3acd":[5,0,0,30,1],
"classcl_1_1_sampler.html#a487aa40df9ababf70fe4c19a0b538f6f":[5,0,0,30,4],
"classcl_1_1_sampler.html#a487aa40df9ababf70fe4c19a0b538f6f":[4,0,0,30,4],
"classcl_1_1_sampler.html#a4c05855fddee1688b229bf333162c794":[4,0,0,30,8],
"classcl_1_1_sampler.html#a4c05855fddee1688b229bf333162c794":[5,0,0,30,8],
"classcl_1_1_sampler.html#a4edef47991d28368cb63f57e924d34bd":[4,0,0,30,7],
"classcl_1_1_sampler.html#a4edef47991d28368cb63f57e924d34bd":[5,0,0,30,7],
"classcl_1_1_sampler.html#a684ea0f7bb85233239ba3a266795c1a4":[5,0,0,30,3],
"classcl_1_1_sampler.html#a684ea0f7bb85233239ba3a266795c1a4":[4,0,0,30,3],
"classcl_1_1_sampler.html#a692268678bf12b7b754009f9ba291fbc":[5,0,0,30,6],
"classcl_1_1_sampler.html#a692268678bf12b7b754009f9ba291fbc":[4,0,0,30,6],
"classcl_1_1_sampler.html#aa32c71d59ca20e83fc283273d0b102cd":[5,0,0,30,2],
"classcl_1_1_sampler.html#aa32c71d59ca20e83fc283273d0b102cd":[4,0,0,30,2],
"classcl_1_1_sampler.html#ae98feb073f7295721af31275530fef5f":[5,0,0,30,5],
"classcl_1_1_sampler.html#ae98feb073f7295721af31275530fef5f":[4,0,0,30,5],
"classcl_1_1_user_event.html":[4,0,0,39],
"classcl_1_1_user_event.html":[5,0,0,39],
"classcl_1_1_user_event.html#a1ee5bc016d511a4fec5f23b50a70821a":[4,0,0,39,1],
"classcl_1_1_user_event.html#a1ee5bc016d511a4fec5f23b50a70821a":[5,0,0,39,1],
"classcl_1_1_user_event.html#a4255beef279789245d402a00830c841f":[5,0,0,39,0],
"classcl_1_1_user_event.html#a4255beef279789245d402a00830c841f":[4,0,0,39,0],
"classcl_1_1_user_event.html#ad1df3a34596fee2bf6f1de6893192ae5":[5,0,0,39,2],
"classcl_1_1_user_event.html#ad1df3a34596fee2bf6f1de6893192ae5":[4,0,0,39,2],
"classcl_1_1detail_1_1_deleter.html":[4,0,0,1,0],
"classcl_1_1detail_1_1_deleter.html":[5,0,0,1,0],
"classcl_1_1detail_1_1_s_v_m_trait_null.html":[4,0,0,1,19],
"classcl_1_1detail_1_1_s_v_m_trait_null.html":[5,0,0,1,19],
"classcl_1_1detail_1_1_wrapper.html":[4,0,0,1,20],
"classcl_1_1detail_1_1_wrapper.html":[5,0,0,1,20],
"classcl_1_1detail_1_1_wrapper_3_01cl__device__id_01_4.html":[5,0,0,1,21],
"classcl_1_1detail_1_1_wrapper_3_01cl__device__id_01_4.html":[4,0,0,1,21],
"classes.html":[5,1],
"files.html":[6,0],
"functions.html":[5,3,0],
"functions.html":[5,3,0,0],
"functions_b.html":[5,3,0,1],
"functions_c.html":[5,3,0,2],
"functions_d.html":[5,3,0,3],
"functions_e.html":[5,3,0,4],
"functions_func.html":[5,3,1],
"functions_func.html":[5,3,1,0],
"functions_func_b.html":[5,3,1,1],
"functions_func_c.html":[5,3,1,2],
"functions_func_d.html":[5,3,1,3],
"functions_func_e.html":[5,3,1,4],
"functions_func_g.html":[5,3,1,5],
"functions_func_i.html":[5,3,1,6],
"functions_func_k.html":[5,3,1,7],
"functions_func_m.html":[5,3,1,8],
"functions_func_n.html":[5,3,1,9],
"functions_func_o.html":[5,3,1,10],
"functions_func_p.html":[5,3,1,11],
"functions_func_r.html":[5,3,1,12],
"functions_func_s.html":[5,3,1,13],
"functions_func_u.html":[5,3,1,14],
"functions_func_w.html":[5,3,1,15],
"functions_g.html":[5,3,0,5],
"functions_i.html":[5,3,0,6],
"functions_k.html":[5,3,0,7],
"functions_m.html":[5,3,0,8],
"functions_n.html":[5,3,0,9],
"functions_o.html":[5,3,0,10],
"functions_p.html":[5,3,0,11],
"functions_r.html":[5,3,0,12],
"functions_s.html":[5,3,0,13],
"functions_t.html":[5,3,0,14],
"functions_type.html":[5,3,2],
"functions_u.html":[5,3,0,15],
"functions_w.html":[5,3,0,16],
"hierarchy.html":[5,2],
"index.html":[],
"index.html#compatibility":[1],
"index.html#example":[3],
"index.html#intro":[0],
"index.html#parameterization":[2],
"namespacecl.html":[4,0,0],
"namespacecl.html#a02c4368c6ce7a1a99132eafd5dc96fa9":[4,0,0,45],
"namespacecl.html#a048aa194c540d1a3178054256db082b9":[4,0,0,42],
"namespacecl.html#a05791e9d5da23b21abd6e319fb262c9f":[4,0,0,44],
"namespacecl.html#a1197a833cdd6664f206b079f2bebd2eb":[4,0,0,47],
"namespacecl.html#a2f71ed9a316daf59c03c0f3ba62f1bd3":[4,0,0,46],
"namespacecl.html#a2f9d06d8196d7a2f4cf196d5bb7e5dd0":[4,0,0,54],
"namespacecl.html#a2fc824c118740089633cc15e7107f3f0":[4,0,0,56],
"namespacecl.html#a45d896e5d437b505648b399dbe1c3cac":[4,0,0,53],
"namespacecl.html#a5c0670097b79b7f6fd2762bae83328f4":[4,0,0,52],
"namespacecl.html#a7aa80934f265ff5c97b715419aa38566":[4,0,0,48],
"namespacecl.html#a8037dc6274012b061edabe1550a2c0ee":[4,0,0,49],
"namespacecl.html#a8e1fce10cd1b8118f51aa91ce0a589e5":[4,0,0,43],
"namespacecl.html#aa1c4d75a33c1d658ca4abae23376f733":[4,0,0,51],
"namespacecl.html#abb2c4e45814ea569a27c39d37471b2a4":[4,0,0,50],
"namespacecl.html#abd957be3ad58ee2932a99ed8bc6cc049":[4,0,0,41],
"namespacecl.html#ae97dc5bb86e2c3c3935280a86cda301c":[4,0,0,55],
"namespacecl.html#aebc48a598e41f0cb98397460ca04ffb6":[4,0,0,40],
"namespacecl.html#af9f49b386b20c55c04a9e6cd21849fd5":[4,0,0,57],
"namespacemembers.html":[4,1,0],
"namespacemembers_func.html":[4,1,1],
"namespacemembers_type.html":[4,1,2],
"namespaces.html":[4,0],
"opencl_8hpp.html":[6,0,0],
"opencl_8hpp.html#a02c4368c6ce7a1a99132eafd5dc96fa9":[6,0,0,67],
"opencl_8hpp.html#a048aa194c540d1a3178054256db082b9":[6,0,0,64],
"opencl_8hpp.html#a05791e9d5da23b21abd6e319fb262c9f":[6,0,0,66],
"opencl_8hpp.html#a1197a833cdd6664f206b079f2bebd2eb":[6,0,0,69],
"opencl_8hpp.html#a2f71ed9a316daf59c03c0f3ba62f1bd3":[6,0,0,68],
"opencl_8hpp.html#a2f9d06d8196d7a2f4cf196d5bb7e5dd0":[6,0,0,76],
"opencl_8hpp.html#a2fc824c118740089633cc15e7107f3f0":[6,0,0,78],
"opencl_8hpp.html#a45d896e5d437b505648b399dbe1c3cac":[6,0,0,75],
"opencl_8hpp.html#a5c0670097b79b7f6fd2762bae83328f4":[6,0,0,74],
"opencl_8hpp.html#a7aa80934f265ff5c97b715419aa38566":[6,0,0,70],
"opencl_8hpp.html#a8037dc6274012b061edabe1550a2c0ee":[6,0,0,71],
"opencl_8hpp.html#a8e1fce10cd1b8118f51aa91ce0a589e5":[6,0,0,65],
"opencl_8hpp.html#aa1c4d75a33c1d658ca4abae23376f733":[6,0,0,73],
"opencl_8hpp.html#abb2c4e45814ea569a27c39d37471b2a4":[6,0,0,72],
"opencl_8hpp.html#abd957be3ad58ee2932a99ed8bc6cc049":[6,0,0,63],
"opencl_8hpp.html#ae97dc5bb86e2c3c3935280a86cda301c":[6,0,0,77],
"opencl_8hpp.html#aebc48a598e41f0cb98397460ca04ffb6":[6,0,0,62],
"opencl_8hpp.html#af9f49b386b20c55c04a9e6cd21849fd5":[6,0,0,79],
"opencl_8hpp_source.html":[6,0,0],
"pages.html":[],
"structcl_1_1_image_format.html":[4,0,0,20],
"structcl_1_1_image_format.html":[5,0,0,20],
"structcl_1_1_image_format.html#a039deeaa451a52448014794e7dae30ba":[5,0,0,20,1],
"structcl_1_1_image_format.html#a039deeaa451a52448014794e7dae30ba":[4,0,0,20,1],
"structcl_1_1_image_format.html#a74296cd49ed08b0521e8b6b26e51608f":[5,0,0,20,3],
"structcl_1_1_image_format.html#a74296cd49ed08b0521e8b6b26e51608f":[4,0,0,20,3],
"structcl_1_1_image_format.html#a935a0799f110ada43afb5ccfacf6197b":[5,0,0,20,2],
"structcl_1_1_image_format.html#a935a0799f110ada43afb5ccfacf6197b":[4,0,0,20,2],
"structcl_1_1_image_format.html#adf48b6e9dfdfefb7583e20826c3b4a14":[5,0,0,20,0],
"structcl_1_1_image_format.html#adf48b6e9dfdfefb7583e20826c3b4a14":[4,0,0,20,0],
"structcl_1_1_local_space_arg.html":[5,0,0,24],
"structcl_1_1_local_space_arg.html":[4,0,0,24],
"structcl_1_1_s_v_m_allocator_1_1rebind.html":[5,0,0,31,0],
"structcl_1_1_s_v_m_allocator_1_1rebind.html":[4,0,0,31,0],
"structcl_1_1_s_v_m_allocator_3_01void_00_01_s_v_m_trait_01_4_1_1rebind.html":[5,0,0,32,0],
"structcl_1_1_s_v_m_allocator_3_01void_00_01_s_v_m_trait_01_4_1_1rebind.html":[4,0,0,32,0],
"structcl_1_1compatibility_1_1make__kernel.html":[4,0,0,0,0],
"structcl_1_1compatibility_1_1make__kernel.html":[5,0,0,0,0],
"structcl_1_1compatibility_1_1make__kernel.html#aaa094f5455d73fae53eb99b374f05eec":[4,0,0,0,0,1],
"structcl_1_1compatibility_1_1make__kernel.html#aaa094f5455d73fae53eb99b374f05eec":[5,0,0,0,0,1],
"structcl_1_1compatibility_1_1make__kernel.html#ab5a793302f7651ad151a1e4b585be5d4":[4,0,0,0,0,0],
"structcl_1_1compatibility_1_1make__kernel.html#ab5a793302f7651ad151a1e4b585be5d4":[5,0,0,0,0,0],
"structcl_1_1detail_1_1_get_info_functor0.html":[4,0,0,1,1],
"structcl_1_1detail_1_1_get_info_functor0.html":[5,0,0,1,1],
"structcl_1_1detail_1_1_get_info_functor1.html":[5,0,0,1,2],
"structcl_1_1detail_1_1_get_info_functor1.html":[4,0,0,1,2],
"structcl_1_1detail_1_1_kernel_argument_handler.html":[5,0,0,1,3],
"structcl_1_1detail_1_1_kernel_argument_handler.html":[4,0,0,1,3],
"structcl_1_1detail_1_1_kernel_argument_handler_3_01_local_space_arg_00_01void_01_4.html":[4,0,0,1,5],
"structcl_1_1detail_1_1_kernel_argument_handler_3_01_local_space_arg_00_01void_01_4.html":[5,0,0,1,5],
"structcl_1_1detail_1_1_kernel_argument_handler_3_01_t_00_01typename_01std_1_1enable__if_3_01std_cb5bfaca8096193f715a7bbe8a3fa84f.html":[5,0,0,1,6],
"structcl_1_1detail_1_1_kernel_argument_handler_3_01_t_00_01typename_01std_1_1enable__if_3_01std_cb5bfaca8096193f715a7bbe8a3fa84f.html":[4,0,0,1,6],
"structcl_1_1detail_1_1_kernel_argument_handler_3_01_t_00_01typename_01std_1_1enable__if_3_9std_10affa824618af864313998f2e6bcf08f.html":[5,0,0,1,7],
"structcl_1_1detail_1_1_kernel_argument_handler_3_01_t_00_01typename_01std_1_1enable__if_3_9std_10affa824618af864313998f2e6bcf08f.html":[4,0,0,1,7],
"structcl_1_1detail_1_1_kernel_argument_handler_3_01cl_1_1_device_command_queue_00_01void_01_4.html":[4,0,0,1,4],
"structcl_1_1detail_1_1_kernel_argument_handler_3_01cl_1_1_device_command_queue_00_01void_01_4.html":[5,0,0,1,4],
"structcl_1_1detail_1_1_reference_handler.html":[5,0,0,1,9],
"structcl_1_1detail_1_1_reference_handler.html":[4,0,0,1,9],
"structcl_1_1detail_1_1_reference_handler_3_01cl__command__queue_01_4.html":[5,0,0,1,10],
"structcl_1_1detail_1_1_reference_handler_3_01cl__command__queue_01_4.html":[4,0,0,1,10],
"structcl_1_1detail_1_1_reference_handler_3_01cl__context_01_4.html":[5,0,0,1,11],
"structcl_1_1detail_1_1_reference_handler_3_01cl__context_01_4.html":[4,0,0,1,11],
"structcl_1_1detail_1_1_reference_handler_3_01cl__device__id_01_4.html":[4,0,0,1,12],
"structcl_1_1detail_1_1_reference_handler_3_01cl__device__id_01_4.html":[5,0,0,1,12],
"structcl_1_1detail_1_1_reference_handler_3_01cl__event_01_4.html":[4,0,0,1,13],
"structcl_1_1detail_1_1_reference_handler_3_01cl__event_01_4.html":[5,0,0,1,13],
"structcl_1_1detail_1_1_reference_handler_3_01cl__kernel_01_4.html":[4,0,0,1,14],
"structcl_1_1detail_1_1_reference_handler_3_01cl__kernel_01_4.html":[5,0,0,1,14],
"structcl_1_1detail_1_1_reference_handler_3_01cl__mem_01_4.html":[4,0,0,1,15],
"structcl_1_1detail_1_1_reference_handler_3_01cl__mem_01_4.html":[5,0,0,1,15],
"structcl_1_1detail_1_1_reference_handler_3_01cl__platform__id_01_4.html":[4,0,0,1,16],
"structcl_1_1detail_1_1_reference_handler_3_01cl__platform__id_01_4.html":[5,0,0,1,16],
"structcl_1_1detail_1_1_reference_handler_3_01cl__program_01_4.html":[4,0,0,1,17],
"structcl_1_1detail_1_1_reference_handler_3_01cl__program_01_4.html":[5,0,0,1,17],
"structcl_1_1detail_1_1_reference_handler_3_01cl__sampler_01_4.html":[4,0,0,1,18],
"structcl_1_1detail_1_1_reference_handler_3_01cl__sampler_01_4.html":[5,0,0,1,18],
"structcl_1_1detail_1_1param__traits.html":[4,0,0,1,8],
"structcl_1_1detail_1_1param__traits.html":[5,0,0,1,8],
"":[4,0,0,1]
};

==> opencl-clhpp-2023.04.17-1-any.pkg.tar.xz: usr/share/doc/opencl-clhpp/navtreeindex2.js <==
var NAVTREEINDEX2 =
{
"opencl_8hpp.html#ab76105928c721c5a922a4c1aea804e87":[6,0,0,0,0,0,75],
"opencl_8hpp.html#abd957be3ad58ee2932a99ed8bc6cc049":[6,0,0,0,0,0,63],
"opencl_8hpp.html#ae48b9857ac37b027d8e946f0cf3c3232":[6,0,0,0,0,0,72],
"opencl_8hpp.html#ae97dc5bb86e2c3c3935280a86cda301c":[6,0,0,0,0,0,77],
"opencl_8hpp.html#aebc48a598e41f0cb98397460ca04ffb6":[6,0,0,0,0,0,62],
"opencl_8hpp.html#af9f49b386b20c55c04a9e6cd21849fd5":[6,0,0,0,0,0,79],
"opencl_8hpp_source.html":[6,0,0,0,0,0],
"pages.html":[],
"structcl_1_1_image_format.html":[4,0,0,18],
"structcl_1_1_image_format.html":[5,0,0,20],
"structcl_1_1_image_format.html#a039deeaa451a52448014794e7dae30ba":[5,0,0,20,1],
"structcl_1_1_image_format.html#a039deeaa451a52448014794e7dae30ba":[4,0,0,18,1],
"structcl_1_1_image_format.html#a74296cd49ed08b0521e8b6b26e51608f":[5,0,0,20,3],
"structcl_1_1_image_format.html#a74296cd49ed08b0521e8b6b26e51608f":[4,0,0,18,3],
"structcl_1_1_image_format.html#a935a0799f110ada43afb5ccfacf6197b":[5,0,0,20,2],
"structcl_1_1_image_format.html#a935a0799f110ada43afb5ccfacf6197b":[4,0,0,18,2],
"structcl_1_1_image_format.html#adf48b6e9dfdfefb7583e20826c3b4a14":[5,0,0,20,0],
"structcl_1_1_image_format.html#adf48b6e9dfdfefb7583e20826c3b4a14":[4,0,0,18,0],
"structcl_1_1_local_space_arg.html":[4,0,0,22],
"structcl_1_1_local_space_arg.html":[5,0,0,24],
"structcl_1_1_s_v_m_allocator_1_1rebind.html":[5,0,0,31,0],
"structcl_1_1_s_v_m_allocator_1_1rebind.html":[4,0,0,29,0],
"structcl_1_1_s_v_m_allocator_3_01void_00_01_s_v_m_trait_01_4_1_1rebind.html":[5,0,0,32,0],
"structcl_1_1_s_v_m_allocator_3_01void_00_01_s_v_m_trait_01_4_1_1rebind.html":[4,0,0,30,0],
"structcl_1_1compatibility_1_1make__kernel.html":[5,0,0,0,0],
"structcl_1_1compatibility_1_1make__kernel.html#aaa094f5455d73fae53eb99b374f05eec":[5,0,0,0,0,1],
"structcl_1_1compatibility_1_1make__kernel.html#ab5a793302f7651ad151a1e4b585be5d4":[5,0,0,0,0,0],
"structcl_1_1detail_1_1_get_info_functor0.html":[5,0,0,1,1],
"structcl_1_1detail_1_1_get_info_functor1.html":[5,0,0,1,2],
"structcl_1_1detail_1_1_kernel_argument_handler.html":[5,0,0,1,3],
"structcl_1_1detail_1_1_kernel_argument_handler_3_01_local_space_arg_00_01void_01_4.html":[5,0,0,1,5],
"structcl_1_1detail_1_1_kernel_argument_handler_3_01_t_00_01typename_01std_1_1enable__if_3_01std_cb5bfaca8096193f715a7bbe8a3fa84f.html":[5,0,0,1,6],
"structcl_1_1detail_1_1_kernel_argument_handler_3_01_t_00_01typename_01std_1_1enable__if_3_9std_10affa824618af864313998f2e6bcf08f.html":[5,0,0,1,7],
"structcl_1_1detail_1_1_kernel_argument_handler_3_01cl_1_1_device_command_queue_00_01void_01_4.html":[5,0,0,1,4],
"structcl_1_1detail_1_1_reference_handler.html":[5,0,0,1,9],
"structcl_1_1detail_1_1_reference_handler_3_01cl__command__queue_01_4.html":[5,0,0,1,10],
"structcl_1_1detail_1_1_reference_handler_3_01cl__context_01_4.html":[5,0,0,1,11],
"structcl_1_1detail_1_1_reference_handler_3_01cl__device__id_01_4.html":[5,0,0,1,12],
"structcl_1_1detail_1_1_reference_handler_3_01cl__event_01_4.html":[5,0,0,1,13],
"structcl_1_1detail_1_1_reference_handler_3_01cl__kernel_01_4.html":[5,0,0,1,14],
"structcl_1_1detail_1_1_reference_handler_3_01cl__mem_01_4.html":[5,0,0,1,15],
"structcl_1_1detail_1_1_reference_handler_3_01cl__platform__id_01_4.html":[5,0,0,1,16],
"structcl_1_1detail_1_1_reference_handler_3_01cl__program_01_4.html":[5,0,0,1,17],
"structcl_1_1detail_1_1_reference_handler_3_01cl__sampler_01_4.html":[5,0,0,1,18],
"structcl_1_1detail_1_1param__traits.html":[5,0,0,1,8]
};
